@@ -5,9 +5,9 @@ pub mod ogg_writer;
 
 use anyhow::Result;
 
-// RTPWriter defines an interface to handle
+// Writer defines an interface to handle
 // the creation of media files
-pub trait RTPWriter {
+pub trait Writer {
     // Add the content of an RTP packet to the media
     fn write_rtp(&mut self, pkt: &rtp::packet::Packet) -> Result<()>;
     // close the media
